pub struct SyncServiceBuilder { /* private fields */ }Implementations
Sourceimpl SyncServiceBuilder
impl SyncServiceBuilder
Sourcepub fn with_offline_mode(self) -> Self
pub fn with_offline_mode(self) -> Self
Enable the “offline” mode for the SyncService.
To learn more about the “offline” mode read the documentation for the
State::Offline enum variant.
Whether to turn SlidingSyncBuilder::share_pos on or off.
Sourcepub fn with_profiles_extension(self) -> Self
pub fn with_profiles_extension(self) -> Self
Enable the Profiles sliding sync extension for the room list service.
Required to merge the global m.status and m.call fields into the
room members and profiles read from this crate.
Sourcepub fn with_room_list_conn_id(self, conn_id: String) -> Self
pub fn with_room_list_conn_id(self, conn_id: String) -> Self
Set a custom conn_id for the room list sliding sync connection.
Sourcepub fn with_room_list_timeline_limit(self, limit: u32) -> Self
pub fn with_room_list_timeline_limit(self, limit: u32) -> Self
Set a custom timeline limit for the room list service.
Sourcepub fn with_parent_span(self, parent_span: Span) -> Self
pub fn with_parent_span(self, parent_span: Span) -> Self
Set the parent tracing span to be used for the tasks within this service.
Sourcepub async fn build(self) -> Result<SyncService, Error>
pub async fn build(self) -> Result<SyncService, Error>
Finish setting up the SyncService.
This creates the underlying sliding syncs, and will not start them in
the background. The resulting SyncService must be kept alive as long
as the sliding syncs are supposed to run.