pub struct SyncServiceBuilder { /* private fields */ }Implementations
Sourceimpl SyncServiceBuilder
impl SyncServiceBuilder
Sourcepub fn with_offline_mode(self) -> Self
pub fn with_offline_mode(self) -> Self
Enable the “offline” mode for the SyncService.
To learn more about the “offline” mode read the documentation for the
State::Offline enum variant.
Whether to turn SlidingSyncBuilder::share_pos on or off.
Sourcepub fn with_parent_span(self, parent_span: Span) -> Self
pub fn with_parent_span(self, parent_span: Span) -> Self
Set the parent tracing span to be used for the tasks within this service.
Sourcepub async fn build(self) -> Result<SyncService, Error>
pub async fn build(self) -> Result<SyncService, Error>
Finish setting up the SyncService.
This creates the underlying sliding syncs, and will not start them in
the background. The resulting SyncService must be kept alive as long
as the sliding syncs are supposed to run.